From: Mehdi Dogguy <mehdi@debian.org>
Date: Tue, 27 Apr 2010 11:44:45 +0200
Subject: [PATCH] Fix some typos
---
cil/src/frontc/cabs2cil.ml | 4 ++--
cil/src/logic/logic_preprocess.ml | 2 +-
cil/src/logic/logic_preprocess.mll | 2 +-
cil/src/logic/logic_typing.ml | 2 +-
man/frama-c.1 | 2 +-
ptests/ptests.ml | 2 +-
src/ai/base.ml | 2 +-
src/ai/base.mli | 2 +-
src/aorai/abstract_ai.ml | 2 +-
src/aorai/bycase_ai.ml | 2 +-
src/kernel/journal.ml | 2 +-
src/kernel/special_hooks.ml | 2 +-
src/lib/qstack.mli | 2 +-
src/memory_state/locations.mli | 4 ++--
src/project/kind.ml | 4 ++--
src/project/kind.mli | 4 ++--
src/scope/dpds_gui.ml | 2 +-
src/slicing/fct_slice.ml | 6 +++---
src/slicing/register.ml | 2 +-
src/slicing/slicingProject.ml | 2 +-
20 files changed, 26 insertions(+), 26 deletions(-)
diff --git a/cil/src/frontc/cabs2cil.ml b/cil/src/frontc/cabs2cil.ml
index 1f83e58..c6c8828 100644
--- a/cil/src/frontc/cabs2cil.ml
+++ b/cil/src/frontc/cabs2cil.ml
@@ -1035,7 +1035,7 @@ module BlockChunk =
let unspecified_chunk c = (* c *)
(* to restore previous behavior (where unspecified evaluation order
- was not explicitely marked), comment out the line below and make
+ was not explicitly marked), comment out the line below and make
unspecified_chunk the identity function.
*)
{ c with unspecified_order = true }
@@ -3777,7 +3777,7 @@ and getIntConstExp ghost (aexp) : exp =
* sizeof/alignof since (for CCured) we can't const-eval those,
* and it's not clear whether they can be bitfield width specifiers
* anyway (since that's where this function is used)
- * -- VP 2006-12-20: C99 explicitely says so (par. 6.6.6)
+ * -- VP 2006-12-20: C99 explicitly says so (par. 6.6.6)
*)
and isIntegerConstant ghost (aexp) : int option =
match doExp (ghost_local_env ghost) true aexp (AExp None) with
diff --git a/cil/src/logic/logic_preprocess.ml b/cil/src/logic/logic_preprocess.ml
index 1698bcb..760b2cd 100644
--- a/cil/src/logic/logic_preprocess.ml
+++ b/cil/src/logic/logic_preprocess.ml
@@ -27,7 +27,7 @@
let debug = Cilmsg.debug_atleast 3 in
let (ppname, ppfile) = Filename.open_temp_file "ppannot" ".c" in
Buffer.output_buffer ppfile macros;
- (* NB: the three extra spaces replace the begining of the annotation
+ (* NB: the three extra spaces replace the beginning of the annotation
in order to keep the columns count accurate (at least until there's
a macro expansion).
*)
diff --git a/cil/src/logic/logic_preprocess.mll b/cil/src/logic/logic_preprocess.mll
index ce51e09..7900bb8 100644
--- a/cil/src/logic/logic_preprocess.mll
+++ b/cil/src/logic/logic_preprocess.mll
@@ -51,7 +51,7 @@
let debug = Cilmsg.debug_atleast 3 in
let (ppname, ppfile) = Filename.open_temp_file "ppannot" ".c" in
Buffer.output_buffer ppfile macros;
- (* NB: the three extra spaces replace the begining of the annotation
+ (* NB: the three extra spaces replace the beginning of the annotation
in order to keep the columns count accurate (at least until there's
a macro expansion).
*)
diff --git a/cil/src/logic/logic_typing.ml b/cil/src/logic/logic_typing.ml
index 95b0635..fe96f31 100644
--- a/cil/src/logic/logic_typing.ml
+++ b/cil/src/logic/logic_typing.ml
@@ -1228,7 +1228,7 @@ struct
| [_] -> check_current_label loc env;
| _ -> error loc
"logic function or predicate %a has multiple labels. \
- They must be instantiated explicitely." Cil.d_logic_var info.l_var_info
+ They must be instantiated explicitly." Cil.d_logic_var info.l_var_info
let rec term env t =
match t.lexpr_node with
diff --git a/man/frama-c.1 b/man/frama-c.1
index fb9fa88..f77e8fa 100644
--- a/man/frama-c.1
+++ b/man/frama-c.1
@@ -113,7 +113,7 @@ Sets verbosity and debugging level to 0.
considers that all numerical addresses in the range
.I min-max
are valid. Bounds are parsed as ocaml integer constants. By default,
-all numerical adresses are considered invalid.
+all numerical addresses are considered invalid.
.TP
.BI \-add\-path\ p1[,p2[...,pn]]
adds directories
diff --git a/ptests/ptests.ml b/ptests/ptests.ml
index e4b3570..ea536b6 100644
--- a/ptests/ptests.ml
+++ b/ptests/ptests.ml
@@ -261,7 +261,7 @@ type config =
(** troplevel full path and options to launch the toplevel on *)
dc_dont_run : bool;
dc_is_explicit_test: bool
- (** set to true for single test files that are explicitely
+ (** set to true for single test files that are explicitly
mentioned on the command line. Overrides dc_dont_run. *)
}
diff --git a/src/ai/base.ml b/src/ai/base.ml
index d156faf..3ec72b5 100644
--- a/src/ai/base.ml
+++ b/src/ai/base.ml
@@ -44,7 +44,7 @@ type t =
| Var of varinfo*validity
| Initialized_Var of varinfo*validity
(** base that is implicitely initialized. *)
- | Null (** base for adresses like [(int* )0x123] *)
+ | Null (** base for addresses like [(int* )0x123] *)
| String of int*string (** String constants *)
| Cell_class of cell_class_attributes (** a class of memory cells *)
diff --git a/src/ai/base.mli b/src/ai/base.mli
index 6182756..dcff08c 100644
--- a/src/ai/base.mli
+++ b/src/ai/base.mli
@@ -32,7 +32,7 @@ type t = private
| Var of Cil_types.varinfo*validity (** Base for uninitialized variables *)
| Initialized_Var of Cil_types.varinfo*validity
(** Base for variables initialized to zero . *)
- | Null (** Base for adresses like [(int* )0x123] *)
+ | Null (** Base for addresses like [(int* )0x123] *)
| String of int*string (** String constants *)
| Cell_class of cell_class_attributes (** A class of memory cells *)
diff --git a/src/aorai/abstract_ai.ml b/src/aorai/abstract_ai.ml
index 4215c9c..8116d11 100644
--- a/src/aorai/abstract_ai.ml
+++ b/src/aorai/abstract_ai.ml
@@ -800,7 +800,7 @@ class visit_propagating_pre_post_constraints (auto:Promelaast.buchautomata) =
in
- (* This computation is done from end to begining *)
+ (* This computation is done from end to beginning *)
prop (List.rev stmt_l) (post_st,post_tr)
in
diff --git a/src/aorai/bycase_ai.ml b/src/aorai/bycase_ai.ml
index 0b75a1d..faa62bb 100644
--- a/src/aorai/bycase_ai.ml
+++ b/src/aorai/bycase_ai.ml
@@ -816,7 +816,7 @@ class visit_propagating_pre_post_constraints_bycase (auto:Promelaast.buchautomat
in
- (* This computation is done from end to begining *)
+ (* This computation is done from end to beginning *)
prop (List.rev stmt_l) (post_st,post_tr)
in
diff --git a/src/kernel/journal.ml b/src/kernel/journal.ml
index f69b752..35e9812 100644
--- a/src/kernel/journal.ml
+++ b/src/kernel/journal.ml
@@ -191,7 +191,7 @@ let write () =
let () =
(* write the journal iff it is enable and
- either an error occurs;
- - or the user explicitely wanted it. *)
+ - or the user explicitly wanted it. *)
if Cmdline.journal_enable then begin
Cmdline.at_error_exit write;
if Cmdline.journal_isset then Cmdline.at_normal_exit write
diff --git a/src/kernel/special_hooks.ml b/src/kernel/special_hooks.ml
index 181276d..c7545c3 100644
--- a/src/kernel/special_hooks.ml
+++ b/src/kernel/special_hooks.ml
@@ -26,7 +26,7 @@ let version () =
Compilation date: %s
Share path: %s (may be overridden with FRAMAC_SHARE variable)
Library path: %s (may be overridden with FRAMAC_LIB variable)
-Plug-in paths: %t(may be overriden with FRAMAC_PLUGIN variable)@."
+Plug-in paths: %t(may be overridden with FRAMAC_PLUGIN variable)@."
Config.version Config.date Config.datadir Config.libdir
(fun fmt -> List.iter (fun s -> Format.fprintf fmt "%s " s)
(Dynamic.default_path ()));
diff --git a/src/lib/qstack.mli b/src/lib/qstack.mli
index ec58d76..658ac30 100644
--- a/src/lib/qstack.mli
+++ b/src/lib/qstack.mli
@@ -49,7 +49,7 @@ module Make(D: DATA) : sig
(** Remove all the elements of a stack. *)
val add: D.t -> t -> unit
- (** Add at the begining of the stack. Complexity: O(1). *)
+ (** Add at the beginning of the stack. Complexity: O(1). *)
val add_at_end: D.t -> t -> unit
(** Add at the end of the stack. Complexity: O(1). *)
diff --git a/src/memory_state/locations.mli b/src/memory_state/locations.mli
index 456c30f..2e2931a 100644
--- a/src/memory_state/locations.mli
+++ b/src/memory_state/locations.mli
@@ -116,7 +116,7 @@ module Location_Bytes : sig
joiner:('a -> 'a -> 'a) -> empty:'a -> t -> 'a
val contains_addresses_of_locals : (M.key -> bool) -> t -> bool
- (** [contains_adresses_of_locals is_local loc] returns [true]
+ (** [contains_addresses_of_locals is_local loc] returns [true]
if [loc] contains the adress of a variable for which
[is_local] returns [true]
*)
@@ -128,7 +128,7 @@ module Location_Bytes : sig
*)
val contains_addresses_of_any_locals : t -> bool
- (** [contains_adresses_of_any_locals loc] returns [true] iff [loc] contains
+ (** [contains_addresses_of_any_locals loc] returns [true] iff [loc] contains
the adress of a local variable or of a formal variable. *)
end
diff --git a/src/project/kind.ml b/src/project/kind.ml
index 647f0a9..aa49a25 100644
--- a/src/project/kind.ml
+++ b/src/project/kind.ml
@@ -366,7 +366,7 @@ dependencies:@\n%s@\n%s@."
Mark.set v 2;
acc
| _, _, Some Only_Select_Dependencies, _ ->
- (* Do explicitely not select the dependencies *)
+ (* Do explicitly not select the dependencies *)
Mark.set v 2;
f v acc
| true, Some _, _, _ ->
@@ -380,7 +380,7 @@ dependencies:@\n%s@\n%s@."
Mark.set v 1;
f v acc
| false, Some Only_Select_Dependencies, None, _ ->
- (* Do explicitely select the dependencies *)
+ (* Do explicitly select the dependencies *)
Mark.set v 1;
acc
in
diff --git a/src/project/kind.mli b/src/project/kind.mli
index 979e633..b3f2394 100644
--- a/src/project/kind.mli
+++ b/src/project/kind.mli
@@ -138,7 +138,7 @@ sig
Selection.t -> Selection.t -> (t -> 'a -> 'a) -> 'a -> 'a
(** [apply_in_order only except f x] folds [f] for of each kind of type [t]
(or for each kind specified by [only] and [except] if one of them is
- non-empty), begining to [acc] and following a topological order of
+ non-empty), beginning to [acc] and following a topological order of
kinds dependencies. *)
val iter_in_order:
@@ -158,7 +158,7 @@ sig
Selection.t -> Selection.t -> (T.t -> 'a -> 'a) -> 'a -> 'a
(** [fold_in_order only except f acc] folds [f v x] for each kind value [v]
of type [T.t] (or for each kind specified by [only] and
- [except] if one of them is non-empty), begining to [acc] and following
+ [except] if one of them is non-empty), beginning to [acc] and following
the same order as apply_in_order. *)
val number_of_applicants: Selection.t -> Selection.t -> int option
diff --git a/src/scope/dpds_gui.ml b/src/scope/dpds_gui.ml
index 4984597..d8b1e3f 100644
--- a/src/scope/dpds_gui.ml
+++ b/src/scope/dpds_gui.ml
@@ -236,7 +236,7 @@ module ShowDef : (DpdCmdSig with type t_in = lval) = struct
^"highlight the statements that define the value of D at L,\n\t"
^"and print a message if a part of D might be undefined.\n\t"
^"Notice that 'undefined' only means here "
- ^"not defined on some path from the begining of the function.")
+ ^"not defined on some path from the beginning of the function.")
let get_info _kf_stmt_opt =
diff --git a/src/slicing/register.ml b/src/slicing/register.ml
index 3a6913f..bbe177a 100644
--- a/src/slicing/register.ml
+++ b/src/slicing/register.ml
@@ -378,7 +378,7 @@ let add_ff_selection proj ff db_select =
let _, select = check_ff_db_select ff db_select in
SlicingProject.add_fct_ff_filter proj ff select
-(** add a persistant selection to the function.
+(** add a persistent selection to the function.
* This might change its slicing level in order to call slices later on. *)
let add_fi_selection proj db_select =
SlicingParameters.debug ~level:1 "[Register.add_fi_selection] %a"
diff --git a/src/slicing/slicingProject.ml b/src/slicing/slicingProject.ml
index 9cf2858..4b9bba6 100644
--- a/src/slicing/slicingProject.ml
+++ b/src/slicing/slicingProject.ml
@@ -53,7 +53,7 @@ let get_name proj = proj.T.name
let add_proj_actions proj actions = proj.T.actions <- actions @ proj.T.actions
(** Add a new slice for the function. It can be the case that it create actions
-* if the function has some persistant selection, that make function calls to
+* if the function has some persistent selection, that make function calls to
* choose.
* @raise SlicingTypes.NoPdg when the function has no PDG.
* *)
--
diff --git a/src/slicing/fct_slice.ml b/src/slicing/fct_slice.ml
index 9bf763c..ec4fd2f 100644
--- a/src/slicing/fct_slice.ml
+++ b/src/slicing/fct_slice.ml
@@ -418,7 +418,7 @@ end = struct
(** compute the marks to propagate in [pdg_caller] when the called function
* have the [to_prop] marks.
* @param fi_to_call is used to compute [more_inputs] only :
* a persistant input mark is not considered as a new input.
* *)
let marks_for_caller_inputs pdg_caller old_marks call to_prop fi_to_call =
assert (not (PdgTypes.Pdg.is_top pdg_caller));
@@ -736,7 +736,7 @@ let examine_calls ff new_marks_in_call_outputs =
in FctMarks.fold_calls process_this_call ff []
(** build a new empty slice in the given [fct_info].
* If the function has some persistant selection, let's copy it in the new slice.
* Notice that there can be at most one slice for the application entry point
* (main), but we allow to have several slice for a library entry point.
* @param build_actions (bool) is useful if the function has some persistent
@@ -885,7 +885,7 @@ let prop_persistant_marks proj fi to_prop actions =
* and [propagate=true], also generates the actions to make every calls to this
* function visible. *)
let add_marks_to_fi proj fi nodes_marks propagate actions =
- SlicingParameters.debug ~level:2 "[Fct_Slice.add_marks_to_fi] (persistant)";
+ SlicingParameters.debug ~level:2 "[Fct_Slice.add_marks_to_fi] (persistent)";
let marks, are_new_marks =
match FctMarks.fi_marks fi with
| Some m -> m, false
@@ -418,7 +418,7 @@ end = struct
* have the [to_prop] marks.
* @param fi_to_call is used to compute [more_inputs] only :
- * a persistant input mark is not considered as a new input.
+ * a persistent input mark is not considered as a new input.
* *)
let marks_for_caller_inputs pdg_caller old_marks call to_prop fi_to_call =
@@ -736,7 +736,7 @@ let examine_calls ff new_marks_in_call_outputs =
in FctMarks.fold_calls process_this_call ff []
(** build a new empty slice in the given [fct_info].
-* If the function has some persistant selection, let's copy it in the new slice.
+* If the function has some persistent selection, let's copy it in the new slice.
* Notice that there can be at most one slice for the application entry point
* (main), but we allow to have several slice for a library entry point.